Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(158)

Unified Diff: ui/gfx/display.h

Issue 15830003: Manual Merge 201756 "Changes how to compute the id of a display." (2nd) (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1500/src/
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/display/display_change_observer_x11.cc ('k') | ui/gfx/display.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/gfx/display.h
===================================================================
--- ui/gfx/display.h (revision 202214)
+++ ui/gfx/display.h (working copy)
@@ -41,14 +41,14 @@
static bool HasForceDeviceScaleFactor();
// Returns 64-bit persistent ID for the specified manufacturer's ID and
// product_code, and the index of the output it is connected to.
// |output_index| is used to distinguish the displays of the same type. For
// example, swapping two identical display between two outputs will not be
// treated as swap. The 'serial number' field in EDID isn't used here because
// it is not guaranteed to have unique number and it may have the same fixed
// value (like 0).
static int64 GetID(uint16 manufacturer_id,
- uint16 product_code,
+ uint32 product_code_hash,
uint8 output_index);
// Sets/Gets unique identifier associated with the display.
« no previous file with comments | « ash/display/display_change_observer_x11.cc ('k') | ui/gfx/display.cc » ('j') | no next file with comments »
@@ -41,14 +41,14 @@
static bool HasForceDeviceScaleFactor();
// Returns 64-bit persistent ID for the specified manufacturer's ID and
- // product_code, and the index of the output it is connected to.
+ // product_code_hash, and the index of the output it is connected to.
// |output_index| is used to distinguish the displays of the same type. For
// example, swapping two identical display between two outputs will not be

Powered by Google App Engine
This is Rietveld 408576698